@@ -125,6 +125,39 @@ class Builds:
 
         return response
 
+    def get_id_by_request_id(self, identifier: int) -> int:
+        """
+        Get build id by request id.
+
+        Args:
+            identifier (int): request identifier.
+
+        Returns:
+            int: build identifier.
+
+        Raises:
+            QBProcessingError: will be raised if resource is not found.
+        """
+        return self.quickbuild.identifiers.get_build_id_by_request_id(identifier)
+
+    def get_id_by_build_name(self, name: str) -> int:
+        """
+        Get build id by build name.
+
+        For example how to get id of latest build in configuration with id 1,
+        name will be `1.latest`
+
+        Args:
+            name (str): build name.
+
+        Returns:
+            int: build identifier.
+
+        Raises:
+            QBProcessingError: will be raised if resource is not found.
+        """
+        return self.quickbuild.identifiers.get_build_id_by_build_name(name)
+
     def get_steps(self, build_id: int) -> str:
         """
         Get build steps.
@@ -193,6 +226,67 @@ class Builds:
 
         return response
 
+    def get_files(self, build_id: int, path: str) -> str:
+        """
+        Get information about published files.
+
+        Args:
+            build_id (int):
+                Build id.
+
+            path (str):
+                Represents the relative path under publish directory of the
+                specified build.
+
+        Returns:
+            str: information about files and directories under the specified path.
+
+        Raises:
+            QBProcessingError: will be raised if specified path does not exist.
+        """
+        params = dict(
+            build_id=build_id,
+            path=path,
+        )
+
+        response = self.quickbuild._request(
+            'GET',
+            'files',
+            callback=response2py,
+            params=params,
+        )
+
+        return response
+
+    def get_notifications(self,
+                          last_notified_build_id: Optional[int] = None
+                          ) -> Union[List[dict], str]:
+        """
+        Get notifications belonging to current user, specified when client
+        instance was initialized.
+
+        Args:
+            last_notified_build_id (Optional[int]):
+                If not specified, the most recent notification will be returned;
+                otherwise, all notifications after specified build will be returned.
+
+        Returns:
+            Union[List[dict], str]: list of builds to be notified.
+        """
+        params = dict()
+
+        if last_notified_build_id:
+            params['last_notified_build_id'] = last_notified_build_id
+
+        response = self.quickbuild._request(
+            'GET',
+            'notifications',
+            callback=response2py,
+            params=params,
+        )
+
+        return response
+
     def search(self,
                count: int,
                *,
