@@ -59,3 +59,38 @@ def test_get_available_count(client):
 
     response = client.resources.get_available_count(1)
     assert response == 5
+
+
+@responses.activate
+def test_update(client):
+    responses.add(
+        responses.POST,
+        re.compile(r'.*/rest/resources'),
+        body='100'
+    )
+
+    response = client.resources.update('')
+    assert response == 100
+
+
+@responses.activate
+def test_create(client):
+    responses.add(
+        responses.POST,
+        re.compile(r'.*/rest/resources'),
+        body='101'
+    )
+
+    response = client.resources.create('')
+    assert response == 101
+
+
+@responses.activate
+def test_delete(client):
+    responses.add(
+        responses.DELETE,
+        re.compile(r'.*/rest/resources/123'),
+    )
+
+    response = client.resources.delete(123)
+    assert response is None
